@@ -32,7 +32,6 @@
 #include <string.h>
 
 #include "gupnp-didl-lite-resource.h"
-#include "gupnp-dlna-private.h"
 #include "xml-util.h"
 
 #define SEC_PER_MIN 60
@@ -60,6 +59,7 @@ enum {
         PROP_PROTOCOL_INFO,
 
         PROP_SIZE,
+        PROP_SIZE64,
         PROP_DURATION,
         PROP_BITRATE,
         PROP_SAMPLE_FREQ,
@@ -180,6 +180,10 @@ gupnp_didl_lite_resource_set_property (GObject      *object,
                 gupnp_didl_lite_resource_set_size (resource,
                                                    g_value_get_long (value));
                 break;
+        case PROP_SIZE64:
+                gupnp_didl_lite_resource_set_size64 (resource,
+                                                     g_value_get_int64 (value));
+                break;
         case PROP_DURATION:
                 gupnp_didl_lite_resource_set_duration
                                 (resource,
@@ -262,6 +266,9 @@ gupnp_didl_lite_resource_get_property (GObject    *object,
         case PROP_SIZE:
                 g_value_set_long (value,
                                   gupnp_didl_lite_resource_get_size (resource));
+        case PROP_SIZE64:
+                g_value_set_int64 (value,
+                                   gupnp_didl_lite_resource_get_size64 (resource));
                 break;
         case PROP_DURATION:
                 g_value_set_long
@@ -464,6 +471,25 @@ gupnp_didl_lite_resource_class_init (GUPnPDIDLLiteResourceClass *klass)
                                     G_PARAM_STATIC_NICK |
                                     G_PARAM_STATIC_BLURB));
 
+        /**
+         * GUPnPDIDLLiteResource:size64
+         *
+         * The size (in bytes) of this resource.
+         **/
+        g_object_class_install_property
+                (object_class,
+                 PROP_SIZE64,
+                 g_param_spec_int64 ("size64",
+                                     "Size64",
+                                     "The size (in bytes) of this resource.",
+                                     -1,
+                                     G_MAXINT64,
+                                     -1,
+                                     G_PARAM_READWRITE |
+                                     G_PARAM_STATIC_NAME |
+                                     G_PARAM_STATIC_NICK |
+                                     G_PARAM_STATIC_BLURB));
+
         /**
          * GUPnPDIDLLiteResource:duration
          *
@@ -747,20 +773,6 @@ gupnp_didl_lite_resource_get_protocol_info (GUPnPDIDLLiteResource *resource)
                            error->message);
 
                 g_error_free (error);
-        } else {
-                /* Try guessing the DLNA profile if not available */
-                if (gupnp_protocol_info_get_dlna_profile (info) == NULL) {
-                        const char *dlna_profile;
-                        const char *mime_type;
-
-                        mime_type = gupnp_protocol_info_get_mime_type (info);
-                        dlna_profile = dlna_guess_profile (resource, mime_type);
-
-                        if (dlna_profile)
-                                gupnp_protocol_info_set_dlna_profile
-                                                             (info,
-                                                              dlna_profile);
-                }
         }
 
         resource->priv->protocol_info = info;
@@ -778,14 +790,29 @@ gupnp_didl_lite_resource_get_protocol_info (GUPnPDIDLLiteResource *resource)
  **/
 long
 gupnp_didl_lite_resource_get_size (GUPnPDIDLLiteResource *resource)
+{
+    return (long) gupnp_didl_lite_resource_get_size64 (resource);
+}
+
+/**
+ * gupnp_didl_lite_resource_get_size64
+ * @resource: A #GUPnPDIDLLiteResource
+ *
+ * Get the size (in bytes) of the @resource.
+ *
+ * Return value: The size (in bytes) of the @resource or -1.
+ **/
+gint64
+gupnp_didl_lite_resource_get_size64 (GUPnPDIDLLiteResource *resource)
 {
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_RESOURCE (resource), -1);
 
-        return xml_util_get_long_attribute (resource->priv->xml_node,
-                                            "size",
-                                            -1);
+        return xml_util_get_int64_attribute (resource->priv->xml_node,
+                                             "size",
+                                             -1);
 }
 
+
 /**
  * gupnp_didl_lite_resource_get_duration
  * @resource: A #GUPnPDIDLLiteResource
@@ -1009,9 +1036,7 @@ gupnp_didl_lite_resource_set_import_uri (GUPnPDIDLLiteResource *resource,
  * @resource: A #GUPnPDIDLLiteResource
  * @info: The protocol string
  *
- * Set the protocol info associated with the @resource. If the
- * #GUPnPProtocolInfo:dlna-profile of @info is not set, an attempt will be made 
- * to guess it for you.
+ * Set the protocol info associated with the @resource.
  *
  * Return value: None.
  **/
@@ -1024,19 +1049,6 @@ gupnp_didl_lite_resource_set_protocol_info (GUPnPDIDLLiteResource *resource,
         g_return_if_fail (GUPNP_IS_DIDL_LITE_RESOURCE (resource));
         g_return_if_fail (GUPNP_IS_PROTOCOL_INFO (info));
 
-        /* Try guessing the DLNA profile if not available */
-        if (gupnp_protocol_info_get_dlna_profile (info) == NULL) {
-                const char *dlna_profile;
-                const char *mime_type;
-
-                mime_type = gupnp_protocol_info_get_mime_type (info);
-                dlna_profile = dlna_guess_profile (resource, mime_type);
-
-                if (dlna_profile)
-                        gupnp_protocol_info_set_dlna_profile (info,
-                                                              dlna_profile);
-        }
-
         str = gupnp_protocol_info_to_string (info);
         xmlSetProp (resource->priv->xml_node,
                     (unsigned char *) "protocolInfo",
@@ -1076,6 +1088,23 @@ gupnp_didl_lite_resource_set_protocol_info (GUPnPDIDLLiteResource *resource,
 void
 gupnp_didl_lite_resource_set_size (GUPnPDIDLLiteResource *resource,
                                    long                   size)
+{
+        gupnp_didl_lite_resource_set_size64 (resource, size);
+}
+
+/**
+ * gupnp_didl_lite_resource_set_size64
+ * @resource: A #GUPnPDIDLLiteResource
+ * @size: The size (in bytes)
+ *
+ * Set the size (in bytes) of the @resource. Passing a negative number will
+ * unset this property.
+ *
+ * Return value: None.
+ **/
+void
+gupnp_didl_lite_resource_set_size64 (GUPnPDIDLLiteResource *resource,
+                                     gint64                 size)
 {
         g_return_if_fail (GUPNP_IS_DIDL_LITE_RESOURCE (resource));
 
@@ -1085,16 +1114,18 @@ gupnp_didl_lite_resource_set_size (GUPnPDIDLLiteResource *resource,
         else {
                 char *str;
 
-                str = g_strdup_printf ("%ld", size);
+                str = g_strdup_printf ("%" G_GINT64_FORMAT, size);
                 xmlSetProp (resource->priv->xml_node,
                             (unsigned char *) "size",
                             (unsigned char *) str);
                 g_free (str);
         }
 
+        g_object_notify (G_OBJECT (resource), "size64");
         g_object_notify (G_OBJECT (resource), "size");
 }
 
+
 /**
  * gupnp_didl_lite_resource_set_duration
  * @resource: A #GUPnPDIDLLiteResource
@@ -1117,7 +1148,7 @@ gupnp_didl_lite_resource_set_duration (GUPnPDIDLLiteResource *resource,
         else {
                 char *str;
 
-                str = g_strdup_printf ("%ld:%.2ld:%.2ld.00",
+                str = g_strdup_printf ("%ld:%.2ld:%.2ld.000",
                                        duration / (60 * 60),
                                        (duration / 60) % 60,
                                        duration % 60);
